plane_common ::types ::backend_state Enum BackendStatus Copy item path Source pub enum BackendStatus {
Scheduled,
Loading,
Starting,
Waiting,
Ready,
Terminating,
HardTerminating,
Terminated,
}The backend has been scheduled to a drone, but has not yet been acknowledged.
This status is only assigned by the controller; the drone will never assign it by definition.
The backend has been assigned to a drone, which is now responsible for loading its image.
Telling Docker to start the container.
Wait for the backend to be ready to accept connections.
The backend is listening for connections.
The backend has been sent a SIGTERM, either because we sent it or the user did,
and we are waiting for it to exit.
Proxies should stop sending traffic to it, but we should not yet release the key.
The backend has been sent a SIGKILL, either because the user sent a hard termination
request or the lock was past the hard-termination deadline.
The backend has exited or been swept.
Returns an integer representation of the status. This is meant to be an
opaque value that can be used for determining if one status comes before
another in the backend lifecycle.
Gaps are intentionally left in these values to provide room for future
statuses.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Serialize this value into the given Serde serializer.
Read more The type returned in the event of a conversion error.
Performs the conversion.
Calls the relevant method on
Visit to extract data from
self.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dst.
Read more Returns the argument unchanged.
Converts to this type from a reference to the input type.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.