pub struct SpawnConfig {
pub id: Option<BackendName>,
pub cluster: Option<ClusterName>,
pub pool: DronePoolName,
pub executable: Value,
pub lifetime_limit_seconds: Option<i32>,
pub max_idle_seconds: Option<i32>,
pub use_static_token: bool,
pub subdomain: Option<Subdomain>,
}Fields
id: Option<BackendName>ID to assign to the new backend. Must be unique. This should only be used if you really need it, otherwise you can leave it blank and let Plane assign a unique ID automatically. This may be removed from future versions of Plane.
cluster: Option<ClusterName>Cluster to spawn to. Uses the controller default if not provided.
pool: DronePoolNameThe drone pool to use for the connect request.
executable: ValueConfig to use to spawn the backend process.
lifetime_limit_seconds: Option<i32>If provided, the maximum amount of time the backend will be allowed to stay alive. Time counts from when the backend is scheduled.
max_idle_seconds: Option<i32>If provided, the maximum amount of time the backend will be allowed to stay alive with no inbound connections to it.
use_static_token: boolIf true, the backend will have a single connection token associated with it at spawn time instead of dynamic tokens for each user.
subdomain: Option<Subdomain>Trait Implementations
Sourceimpl Clone for SpawnConfig
impl Clone for SpawnConfig
Sourcefn clone(&self) -> SpawnConfig
fn clone(&self) -> SpawnConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more